@@ -2,7 +2,7 @@
 # Package       HiPi::Apps::Control
 # Description:  Control RPi Basics
 # Created       Mon Feb 25 13:27:30 2013
-# SVN Id        $Id: Control.pm 1689 2013-03-23 13:56:47Z Mark Dootson $
+# SVN Id        $Id: Control.pm 24 2016-03-05 12:23:13Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,7 +22,7 @@ use Wx qw( :id :bitmap );
 use HiPi::BCM2835;
 use HiPi;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 __PACKAGE__->create_accessors( qw( devmem ) );
 
@@ -41,10 +41,10 @@ sub OnSetApplicationDetail {
     $self->SetVendorDisplayName('Mark Dootson');
     $self->SetClassName('hipictrlguiclass');
     
-    $self->copyright('Copyright (c)2013 Mark Dootson');
+    $self->copyright('Copyright (c)2013 - 2016 Mark Dootson');
     $self->description('GUI control for Raspberry Pi GPIO pads and devices');
     $self->version( $HiPi::VERSION );
-    $self->supporturl( 'http://raspberrypi.citrusperl.com' );
+    $self->supporturl( 'http://raspberry.znix.com' );
     
     $self->singleinstance( 1 );
 }
