@@ -2,7 +2,7 @@
 # Package       HiPi::Device::GPIO
 # Description:  System GPIO Device
 # Created       Wed Feb 20 02:40:29 2013
-# SVN Id        $Id: GPIO.pm 62 2016-03-14 23:49:47Z Mark Dootson $
+# SVN Id        $Id: GPIO.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,8 +22,9 @@ use HiPi::Constant qw( :raspberry );
 use Carp;
 use HiPi::Device::GPIO::Pin;
 use Time::HiRes;
+use HiPi::Utils qw( :all );
 
-our $VERSION ='0.42';
+our $VERSION ='0.44';
 
 use constant {
     DEV_GPIO_PIN_STATUS_NONE         => 0x00,
@@ -82,7 +83,7 @@ sub export_pin {
         }
     }
     
-    if( $gname ) {
+    if( $gname && !uses_device_tree ) {
         # change exported permissions
         for my $fname ( qw(value edge direction active_low) ) {
             my $file = qq($pinroot/$fname);
