@@ -2,7 +2,7 @@
 # Package       HiPi::Device::SPI
 # Description:  Wrapper for SPI communucation
 # Created       Fri Nov 23 13:55:49 2012
-# SVN Id        $Id: SPI.pm 62 2016-03-14 23:49:47Z Mark Dootson $
+# SVN Id        $Id: SPI.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2012 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -23,10 +23,10 @@ use XSLoader;
 use Carp;
 use HiPi::Constant qw( :raspberry );
 use HiPi;
-use HiPi::Utils qw( is_raspberry );
+use HiPi::Utils qw( :all );
 use Try::Tiny;
 
-our $VERSION ='0.42';
+our $VERSION ='0.44';
 
 __PACKAGE__->create_accessors( qw ( fh fno delay speed bitsperword ) );
 
@@ -86,10 +86,11 @@ _register_exported_constants qw(
     SPI_SPEED_MHZ_32
 );
 
-our @_moduleinfo = (
-    { name => 'spi_bcm2708', params => {}, },
-    { name => 'spidev',      params => { bufsiz => 4096 }, },
-);
+our @_moduleinfo = ( system_type eq 'wheezy' )
+    ? ( { name => 'spi_bcm2708', params => {}, },
+        { name => 'spidev',      params => { bufsiz => 4096 }, },
+       )
+    : ( { name => 'spi_bcm2385', params => {}, }, );
 
 sub get_module_info {
     return @_moduleinfo;
