@@ -2,7 +2,7 @@
 # Package       HiPi::Pin
 # Description:  GPIO / Extender Pin
 # Created       Wed Feb 20 04:39:18 2013
-# SVN Id        $Id: Pin.pm 1754 2013-04-27 00:01:50Z Mark Dootson $
+# SVN Id        $Id: Pin.pm 22 2016-03-04 21:38:30Z Mark Dootson $
 # Copyright:    Copyright (c) 2013 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -61,13 +61,10 @@ sub interrupt {
 sub set_pud {
     my($self, $newval) = @_;
     my $rval;
-    given( $newval ) {
-        when( [ RPI_PUD_OFF, RPI_PUD_DOWN, RPI_PUD_UP ] ) {
-            $rval = $self->_do_setpud( $newval );
-        }
-        default {
-            croak(qq(Invalid PUD setting $newval));
-        }
+    if( $newval == RPI_PUD_OFF || $newval == RPI_PUD_DOWN || $newval == RPI_PUD_UP )  {
+        $rval = $self->_do_setpud( $newval );
+    } else {
+        croak(qq(Invalid PUD setting $newval));
     }
     return $rval;
 }
