@@ -2,7 +2,7 @@
 # Package       HiPi::RaspberryPi
 # Description:  Data from, inter alia, /proc/cpuinfo
 # Created       Sat Nov 24 00:30:35 2012
-# SVN Id        $Id: RaspberryPi.pm 62 2016-03-14 23:49:47Z Mark Dootson $
+# SVN Id        $Id: RaspberryPi.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2012-2015 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -23,7 +23,7 @@ require Exporter;
 use base qw( Exporter );
 use Carp;
 
-our $VERSION ='0.42';
+our $VERSION ='0.44';
 
 our @EXPORT_OK = qw(
     system_is_windows
@@ -34,12 +34,13 @@ our @EXPORT_OK = qw(
     system_is_raspberry_3
     system_uses_device_tree
     system_home_directory
+    system_systype
 );
                     
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 our ($_israspberry, $_isunix, $_iswindows, $_ismac, $_israspberry_2,
-     $_israspberry_3, $_uses_device_tree, $_homedir, $_sysconfig ) = (0,0,0,0,0,0, '', undef);
+     $_israspberry_3, $_uses_device_tree, $_homedir, $_sysconfig, $_systype ) = (0,0,0,0,0,0, '', undef, undef);
 
 sub system_is_windows { $_iswindows; }
 sub system_is_unix { $_isunix; }
@@ -49,6 +50,19 @@ sub system_is_raspberry_2 { $_israspberry_2; }
 sub system_is_raspberry_3 { $_israspberry_3; }
 sub system_uses_device_tree { $_uses_device_tree; }
 sub system_home_directory { $_homedir; }
+sub system_systype { $_systype; }
+
+{
+    my $perlversion = $^V;
+	$perlversion =~ s/^v//;
+	my($major, $minor, $release) = split(/\./, $perlversion);
+	if ($minor <= 14 ) {
+        $_systype = 'wheezy';
+    } else {
+		$_systype = 'current';
+	}
+}
+
 
 our %_revstash = (
     'beta'      => { release => 'Q1 2012', model => 'Raspberry Pi Model B Revision beta', revision => 1, pinplan => 1, memory => 256, manufacturer => 'Generic' },
@@ -104,6 +118,18 @@ our %_revinfostash = (
         '9' => 'Raspberry Pi Zero',
         
     },
+    typepinplan => {
+        '0' => 2,
+        '1' => 2,
+        '2' => 3,
+        '3' => 3,
+        '4' => 3,
+        '5' => 1,
+        '6' => 2,
+        '7' => 3,
+        '8' => 3,
+        '9' => 3,
+    },
     release => {
         '0' => 'Q1 2013',
         '1' => 'Q3 2012',
@@ -192,7 +218,7 @@ our %_cpuinfostash: shared;
             $binfo->{revision} = $schemerev;
             $binfo->{memory}   = $_revinfostash{memsize}->{$schemesize} || 256;
             $binfo->{manufacturer} = $_revinfostash{manufacturer}->{$schememanu} || 'Sony';
-            $binfo->{pinplan} = $basepinplan;
+            $binfo->{pinplan} =  $_revinfostash{typepinplan}->{$schemetype} || $basepinplan;
             $binfo->{processor} = $_revinfostash{processor}->{$schemeproc} || 'BCM2835';
             
             $_israspberry_3 = ( $schemetype >= 8  ) ? 1 : 0;
