@@ -2,7 +2,7 @@
 # Package       HiPi::Utils
 # Description:  HiPi Utilities
 # Created       Sun Feb 24 05:16:17 2013
-# SVN Id        $Id: Utils.pm 62 2016-03-14 23:49:47Z Mark Dootson $
+# SVN Id        $Id: Utils.pm 71 2016-03-15 16:22:29Z Mark Dootson $
 # Copyright:    Copyright (c) 2013-2015 Mark Dootson
 # Licence:      This work is free software; you can redistribute it and/or modify it 
 #               under the terms of the GNU General Public License as published by the 
@@ -22,7 +22,7 @@ use base qw( Exporter );
 use XSLoader;
 use HiPi::RaspberryPi qw( :all );
 
-our $VERSION ='0.42';
+our $VERSION ='0.44';
 
 our $defaultuser = 'pi';
 
@@ -42,6 +42,7 @@ our @EXPORT_OK = qw(
     is_raspberry_2
     is_raspberry_3
     uses_device_tree
+    system_type
 );
                     
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
@@ -54,6 +55,7 @@ sub is_windows { system_is_windows; }
 sub is_mac { system_is_mac; }
 sub is_unix { system_is_unix; }
 sub home_directory { system_home_directory; }
+sub system_type { system_systype; }
 
 XSLoader::load('HiPi::Utils', $VERSION) if is_raspberry();
 
@@ -205,7 +207,7 @@ sub set_udev_rules {
         create_system_group($group);
     }
     
-    {
+    unless( uses_device_tree ) {
         # FIX Up permissions on export / unexport and any existing exports
         
         my $group = ( $rh->{gpio}->{active} ) ? $rh->{gpio}->{group} : 'root';
@@ -291,6 +293,7 @@ sub parse_modprobe_conf {
 
 sub set_modprobe_conf {
     my $rh = shift;
+    return if uses_device_tree;
     require HiPi;
     my $modfile = '/etc/modprobe.d/hipi.conf';
     
